==> joomla-1.6.0.tbz: www/joomla/libraries/joomla/html/parameter/element/modulelayouts.php <==
<?php
/**
 * @version		$Id: modulelayouts.php 20196 2011-01-09 02:40:25Z ian $
 * @copyright	Copyright (C) 2005 - 2011 Open Source Matters, Inc. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined('JPATH_BASE') or die;

require_once dirname(__FILE__).DS.'list.php';

/**
 * Parameter to display a list of the layouts for a module from the module or default template overrides.
 *
 * @package		Joomla.Framework
 * @subpackage	Parameter
 */
class JElementModuleLayouts extends JElementList
{
	/**
	 * @var		string
	 */
	protected $_name = 'ModuleLayouts';

	/**
	 * Get the options for the list.
	 */
	protected function _getOptions(&$node)
	{
		$clientId = ($v = $node->attributes('client_id')) ? $v : 0;

		$options	= array();
		$path1		= null;
		$path2		= null;

		// Load template entries for each menuid
		$db		= JFactory::getDBO();
		$query	= $db->getQuery(true);
		$query->select('template');
		$query->from('#__template_styles');
		$query->where('client_id = '.(int) $clientId);
		$query->where('home = 1');
		$db->setQuery($query);
		$template	= $db->loadResult();

		if ($module = $node->attributes('module')) {
			$base	= ($clientId == 1) ? JPATH_ADMINISTRATOR : JPATH_SITE;
			$module	= preg_replace('#\W#', '', $module);
			$path1	= $base.DS.'modules'.DS.$module.DS.'tmpl';
			$path2	= $base.DS.'templates'.DS.$template.DS.'html'.DS.$module;
			$options[]	= JHTML::_('select.option', '', '');
		}

		if ($path1 && $path2) {
			jimport('joomla.filesystem.file');
			$path1 = JPath::clean($path1);
			$path2 = JPath::clean($path2);

			$files	= JFolder::files($path1, '^[^_]*\.php$');
			foreach ($files as $file) {
				$options[]	= JHTML::_('select.option', JFile::stripExt($file));
			}

			if (is_dir($path2) && $files = JFolder::files($path2, '^[^_]*\.php$')) {
				$options[]	= JHTML::_('select.optgroup', JText::_('JOPTION_FROM_DEFAULT'));
				foreach ($files as $file) {
					$options[]	= JHTML::_('select.option', JFile::stripExt($file));
				}
				$options[]	= JHTML::_('select.optgroup', JText::_('JOPTION_FROM_DEFAULT'));
			}
		}

		// Merge any additional options in the XML definition.
		$options = array_merge(parent::_getOptions($node), $options);

		return $options;
	}
}

==> joomla-1.7.3.tbz: www/joomla/libraries/joomla/html/parameter/element/modulelayouts.php <==
<?php
/**
 * @package     Joomla.Platform
 * @subpackage  HTML
 *
 * @copyright   Copyright (C) 2005 - 2011 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('JPATH_PLATFORM') or die;

require_once dirname(__FILE__).'/list.php';

/**
 * Parameter to display a list of the layouts for a module from the module or default template overrides.
 *
 * @package     Joomla.Platform
 * @subpackage  Parameter
 * @deprecated  Use JForm instead
 */
class JElementModuleLayouts extends JElementList
{
	/**
	 * @var		string
	 */
	protected $_name = 'ModuleLayouts';

	/**
	 * Get the options for the list.
	 * @since   11.1
	 *
	 * @deprecated    12.1
	 */
	protected function _getOptions(&$node)
	{
		$clientId = ($v = $node->attributes('client_id')) ? $v : 0;

		$options	= array();
		$path1		= null;
		$path2		= null;

		// Load template entries for each menuid
		$db		= JFactory::getDBO();
		$query	= $db->getQuery(true);
		$query->select('template');
		$query->from('#__template_styles');
		$query->where('client_id = '.(int) $clientId);
		$query->where('home = 1');
		$db->setQuery($query);
		$template	= $db->loadResult();

		if ($module = $node->attributes('module')) {
			$base	= ($clientId == 1) ? JPATH_ADMINISTRATOR : JPATH_SITE;
			$module	= preg_replace('#\W#', '', $module);
			$path1	= $base . '/modules/' . $module . '/tmpl';
			$path2	= $base . '/templates/' . $template . '/html/' . $module;
			$options[]	= JHTML::_('select.option', '', '');
		}

		if ($path1 && $path2) {
			jimport('joomla.filesystem.file');
			$path1 = JPath::clean($path1);
			$path2 = JPath::clean($path2);

			$files	= JFolder::files($path1, '^[^_]*\.php$');
			foreach ($files as $file) {
				$options[]	= JHTML::_('select.option', JFile::stripExt($file));
			}

			if (is_dir($path2) && $files = JFolder::files($path2, '^[^_]*\.php$')) {
				$options[]	= JHTML::_('select.optgroup', JText::_('JOPTION_FROM_DEFAULT'));
				foreach ($files as $file) {
					$options[]	= JHTML::_('select.option', JFile::stripExt($file));
				}
				$options[]	= JHTML::_('select.optgroup', JText::_('JOPTION_FROM_DEFAULT'));
			}
		}

		// Merge any additional options in the XML definition.
		$options = array_merge(parent::_getOptions($node), $options);

		return $options;
	}
}
